@@ -136,12 +136,12 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="159"/>
         <source>win32-build [Windows XP and 7]</source>
-        <translation>win32-build [Windows XP and 7]</translation>
+        <translation>win32-build [Windows XP и 7]</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="160"/>
         <source>old win32-build [Windows Vista]</source>
-        <translation>old win32-build [Windows Vista]</translation>
+        <translation>старият win32-build [Windows Vista]</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="161"/>
@@ -196,57 +196,57 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="62"/>
+        <location filename="../src/core/core.cpp" line="63"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>е приложение за различни платформи за бързо създаване на екранни снимки на вашия работен плот.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="66"/>
+        <location filename="../src/core/core.cpp" line="67"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Създаване на снимка на целия екран</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="70"/>
+        <location filename="../src/core/core.cpp" line="71"/>
         <source>Take a screenshot of the active window</source>
         <translation>Създаване на снимка на активния прозорец</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="74"/>
+        <location filename="../src/core/core.cpp" line="75"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Създаване на снимка на област от екрана</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="78"/>
+        <location filename="../src/core/core.cpp" line="79"/>
         <source>Run the application with a hidden main window</source>
         <translation>Стартиране на приложението със скрит главен прозорец</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved</source>
         <translation>Снимката е запазена</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved to </source>
         <translation>Снимката е запазена в </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="477"/>
+        <location filename="../src/core/core.cpp" line="478"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Името на записания файл се копира в клипборда</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="483"/>
+        <location filename="../src/core/core.cpp" line="484"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>Пътят на записания файл се копира в клипборда</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Copied</source>
         <translation>Копиран</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Снимката е копирана в клипборда</translation>
     </message>
@@ -365,33 +365,33 @@
         <translation>Изход</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="342"/>
         <source>Screenshot </source>
         <translation>Снимка на екрана </translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="346"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Щракнете двукратно, за да отворите снимката в приложението за преглед на изображения по подразбиране</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="355"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="486"/>
         <source>Hide</source>
         <translation>Скриване</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="493"/>
         <source>Show</source>
         <translation>Показване</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="546"/>
         <source>%1 Files</source>
         <translation>%1 файла</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="568"/>
         <source>Save As...</source>
         <translation>Запазване като...</translation>
     </message>
