@@ -41,17 +41,17 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="34"/>
         <source>using Qt %1</source>
-        <translation type="unfinished"></translation>
+        <translation>verwendet Qt %1</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="105"/>
         <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="108"/>
         <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Lizenziert als &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="119"/>
@@ -196,57 +196,57 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved</source>
         <translation>Gespeichert</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="477"/>
+        <location filename="../src/core/core.cpp" line="478"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Der Name der gespeicherten Datei wird in die Zwischenablage kopiert</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Copied</source>
         <translation>Kopiert</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved to </source>
         <translation>Gespeichert nach </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="62"/>
+        <location filename="../src/core/core.cpp" line="63"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>ist eine plattformunabhängige Anwendung, um Bildschirmfotos aufzunehmen.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="66"/>
+        <location filename="../src/core/core.cpp" line="67"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Mache einen Screenshot des gesamten Bildschirms</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="70"/>
+        <location filename="../src/core/core.cpp" line="71"/>
         <source>Take a screenshot of the active window</source>
         <translation>Mache einen Screenshot des aktiven Fensters</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="74"/>
+        <location filename="../src/core/core.cpp" line="75"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Mache einen Screenshot eines Bildschirmausschnitts</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="78"/>
+        <location filename="../src/core/core.cpp" line="79"/>
         <source>Run the application with a hidden main window</source>
         <translation>Führe die Anwendung in verborgenem Hauptfenster aus</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="483"/>
+        <location filename="../src/core/core.cpp" line="484"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>Der Pfad zur gespeicherten Datei wird in die Zwischenablage kopiert</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Das Bildschirmfoto wird in die Zwischenablage kopiert</translation>
     </message>
@@ -355,18 +355,18 @@
         <translation>Kopieren</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="346"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Doppelklicken, um das Bildschirmfoto in einem externen Bildbetrachter zu öffnen</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="355"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="486"/>
         <source>Hide</source>
         <translation>Verbergen</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="546"/>
         <source>%1 Files</source>
         <translation>%1 Dateien</translation>
     </message>
@@ -376,7 +376,7 @@
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="342"/>
         <source>Screenshot </source>
         <translation>Bildschirmfoto </translation>
     </message>
@@ -386,12 +386,12 @@
         <translation>Keine</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="493"/>
         <source>Show</source>
         <translation>Anzeigen</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="568"/>
         <source>Save As...</source>
         <translation>Speichern als...</translation>
     </message>
@@ -637,8 +637,8 @@ Doppelklick oder Enter um ein Bildschirmfoto aufzunehmen.</translation>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation>Wenn dies nicht aktiviert ist, kann der ausgewählte Bereich
-größer werden um bis an den äußeren Rand zu reichen</translation>
+        <translation>Wenn die Option deaktiviert ist, kann der ausgewählte Bereich
+größer werden, um an die äußeren Kanten zu passen</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
