@@ -31,17 +31,17 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="34"/>
         <source>using Qt %1</source>
-        <translation type="unfinished"></translation>
+        <translation>koristi Qt %1</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="105"/>
         <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Web stranica – &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="108"/>
         <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;a href=%1&gt;GPL v2&lt;/a&gt; licenca</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="112"/>
@@ -196,57 +196,57 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="62"/>
+        <location filename="../src/core/core.cpp" line="63"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>je višeplatformski program za brzo snimanje radne površine.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="66"/>
+        <location filename="../src/core/core.cpp" line="67"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Snimi cijeli ekran</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="70"/>
+        <location filename="../src/core/core.cpp" line="71"/>
         <source>Take a screenshot of the active window</source>
         <translation>Snimi aktivan prozor</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="74"/>
+        <location filename="../src/core/core.cpp" line="75"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Snimi odabrano područje na ekranu</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="78"/>
+        <location filename="../src/core/core.cpp" line="79"/>
         <source>Run the application with a hidden main window</source>
         <translation>Pokreni program sa skrivenim glavnim prozorom</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved</source>
         <translation>Spremljeno</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved to </source>
         <translation>Spremljeno u </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="477"/>
+        <location filename="../src/core/core.cpp" line="478"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Ime spremljene datoteke je kopirano u međuspremnik</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="483"/>
+        <location filename="../src/core/core.cpp" line="484"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>Staza do spremljene datoteke je kopirana u međuspremnik</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Copied</source>
         <translation>Kopirano</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Snimka ekrana je kopirana u međuspremnik</translation>
     </message>
@@ -365,33 +365,33 @@
         <translation>Zatvori</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="342"/>
         <source>Screenshot </source>
         <translation>Snimka ekrana</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="346"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Dvostrukim pritiskom otvori snimku ekrana u vanjskom standardnom programu za prikaz slika</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="355"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="486"/>
         <source>Hide</source>
         <translation>Sakrij</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="493"/>
         <source>Show</source>
         <translation>Prikaži</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="546"/>
         <source>%1 Files</source>
         <translation>%1 datoteke</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="568"/>
         <source>Save As...</source>
         <translation>Spremi kao …</translation>
     </message>
