@@ -196,57 +196,57 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved</source>
         <translation>Сохранено</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="477"/>
+        <location filename="../src/core/core.cpp" line="478"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Имя сохранённого файла скопировано в буфер обмена</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Copied</source>
         <translation>Скопировано</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="455"/>
+        <location filename="../src/core/core.cpp" line="456"/>
         <source>Saved to </source>
         <translation>Сохранено в </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="62"/>
+        <location filename="../src/core/core.cpp" line="63"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>кроссплатформенное приложение для быстрого создания снимков вашего рабочего стола.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="66"/>
+        <location filename="../src/core/core.cpp" line="67"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Сделать снимок всего экрана</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="70"/>
+        <location filename="../src/core/core.cpp" line="71"/>
         <source>Take a screenshot of the active window</source>
         <translation>Сделать снимок активного окна</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="74"/>
+        <location filename="../src/core/core.cpp" line="75"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Сделать снимок выбранной области экрана</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="78"/>
+        <location filename="../src/core/core.cpp" line="79"/>
         <source>Run the application with a hidden main window</source>
         <translation>Запустить приложение со скрытым главным окном</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="483"/>
+        <location filename="../src/core/core.cpp" line="484"/>
         <source>Path to saved file is copied to the clipboard</source>
         <translation>Путь к сохранённому файлу скопирован в буфер обмена</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="505"/>
+        <location filename="../src/core/core.cpp" line="506"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Снимок экрана скопирован в буфер обмена</translation>
     </message>
@@ -254,7 +254,7 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="342"/>
         <source>Screenshot </source>
         <translation>Снимок экрана </translation>
     </message>
@@ -279,13 +279,13 @@
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="346"/>
         <source>Double click to open screenshot in external default image viewer</source>
         <translation>Двойной щелчок откроет снимок экрана во внешнем просмотрщике</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
-        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="355"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="486"/>
         <source>Hide</source>
         <translation>Скрыть окно</translation>
     </message>
@@ -305,17 +305,17 @@
         <translation>Ни одного</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="493"/>
         <source>Show</source>
         <translation>Показать окно</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="546"/>
         <source>%1 Files</source>
         <translation>%1 Файлы</translation>
     </message>
     <message>
-        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
+        <location filename="../src/core/ui/mainwindow.cpp" line="568"/>
         <source>Save As...</source>
         <translation>Сохранить как...</translation>
     </message>
@@ -450,7 +450,7 @@ to take a screenshot.</source>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="192"/>
         <source>Default saving image format</source>
-        <translation>Формат скриншотов по умолчанию</translation>
+        <translation>Стандартный формат сохранения снимков</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="316"/>
@@ -515,17 +515,17 @@ to take a screenshot.</source>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="586"/>
         <source>New screen</source>
-        <translation>Новый скриншот</translation>
+        <translation>Новый снимок экрана</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="591"/>
         <source>Save screen</source>
-        <translation>Сохранить скриншот</translation>
+        <translation>Сохранить снимок экрана</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="596"/>
         <source>Copy screen</source>
-        <translation>Копировать скриншот</translation>
+        <translation>Копировать снимок экрана</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="606"/>
